@@ -247,6 +247,7 @@ sub _build_app {
     ###################################################
     my $c = Thruk::Context->new($self, {'PATH_INFO' => '/dummy-internal'.__FILE__.':'.__LINE__});
     if($c->config->{'use_lmd_core'}) {
+        local $Thruk::Globals::c = $c;
         require Thruk::Utils::LMD;
         Thruk::Utils::LMD::check_initial_start($c, $config, 1);
     }
@@ -561,7 +562,7 @@ sub _check_exit_reason {
     ## no critic
     if($reason =~ m|Thruk::Utils::CLI::from_local|mx && -t 0 && $sig eq 'INT') {
     ## use critic
-        # this means someone hit ctrl+c, no need for a stracktrace then
+        # this means someone hit ctrl+c, no need for a stacktrace then
         printf(STDERR "\nbailing out, got signal SIG%s\n", $sig);
         return;
     }
@@ -585,10 +586,11 @@ sub _check_exit_reason {
     # print stacktrace
     my $log = \&_error;
     if($request_runtime >= 20 && $sig eq 'TERM') {
-        _error("got signal %s while handling %s request, possible timeout in %s\n", $sig, $c->req->method, $url);
+        &{$log}("got signal %s while handling %s request, possible timeout in %s\n", $sig, $c->req->method, $url);
     } else {
-        _warn("got signal %s while handling %s request in %s\n", $sig, $c->req->method, $url);
+        return if $ENV{'THRUK_NO_SHUTDOWN_WARNINGS'};
         $log = \&_warn;
+        &{$log}("got signal %s while handling %s request in %s\n", $sig, $c->req->method, $url);
     }
     &{$log}("User:       %s\n", $c->stash->{'remote_user'}) if $c->stash->{'remote_user'};
     &{$log}("Runtime:    %.2fs\n", $request_runtime);
